import {expect} from 'chai'
import getOpenAdsConfig from '../../../src/vendors/openAds/config'

describe('getOpenAdsConfig', () => {
  it('should return the config if openAds is enabled for prod', () => {
    const expectedOpenAdsConfig = {
      openAds: {
        script: '//c.dcdn.es/openads/infojobs/InfojobsOpenAdsClient.pro.js',
        consents: {
          purposes: []
        }
      }
    }

    const {config: openAdsConfig} = getOpenAdsConfig({
      portal: 'es',
      environment: '',
      path: '/'
    })
    expect(openAdsConfig).to.be.deep.equal(expectedOpenAdsConfig)
  })

  it('should return the config if openAds is enabled for pre', () => {
    const expectedOpenAdsConfig = {
      openAds: {
        script: '//c.dcdn.es/openads/infojobs/InfojobsOpenAdsClient.pre.js',
        consents: {
          purposes: []
        }
      }
    }

    const {config: openAdsConfig} = getOpenAdsConfig({
      portal: 'es',
      environment: 'sbx',
      path: '/'
    })
    expect(openAdsConfig).to.be.deep.equal(expectedOpenAdsConfig)
  })

  it('should return an empty object if optimizely is not enabled', () => {
    const expectedOptimizelyConfig = {}

    const {config: optimizelyConfig} = getOpenAdsConfig({
      portal: 'es',
      environment: '',
      path: '/random-path'
    })

    expect(optimizelyConfig).to.be.deep.equal(expectedOptimizelyConfig)
  })

  it('should return an empty for italy', () => {
    const expectedOptimizelyConfig = {}

    const {config: optimizelyConfig} = getOpenAdsConfig({
      portal: 'it',
      path: '/random-path-not-included'
    })

    expect(optimizelyConfig).to.be.deep.equal(expectedOptimizelyConfig)
  })
})
